@@ -24,4 +24,7 @@ class CMDType(enum.Enum):
 	SEQUENCEREPLY = 20
 
 	LISTAGENTS = 100
-	AGENTINFO = 101
\ No newline at end of file
+	AGENTINFO = 101
+
+	SDSRV = 200
+	WRAPSSL = 201
\ No newline at end of file
